pub enum EventSendState {
NotSentYet {
progress: Option<MediaUploadProgress>,
},
SendingFailed {
error: Arc<Error>,
is_recoverable: bool,
},
Sent {
event_id: OwnedEventId,
},
}Expand description
This type represents the “send state” of a local event timeline item.
Variants
NotSentYet
The local event has not been sent yet.
Fields

progress: Option<MediaUploadProgress>The progress of the sending operation, if the event involves a media upload.
SendingFailed
The local event has been sent to the server, but unsuccessfully: The sending has failed.
Fields
Sent
The local event has been sent successfully to the server.
Fields

event_id: OwnedEventIdThe event ID assigned by the server.