pub enum TimelineItemContent {
MsgLike(MsgLikeContent),
MembershipChange(RoomMembershipChange),
ProfileChange(MemberProfileChange),
OtherState(OtherState),
FailedToParseMessageLike {
event_type: MessageLikeEventType,
error: Arc<Error>,
},
FailedToParseState {
event_type: StateEventType,
state_key: String,
error: Arc<Error>,
},
CallInvite,
RtcNotification,
}Expand description
The content of an EventTimelineItem.
Variants
MsgLike(MsgLikeContent)
MembershipChange(RoomMembershipChange)
A room membership change.
ProfileChange(MemberProfileChange)
A room member profile change.
OtherState(OtherState)
Another state event.
FailedToParseMessageLike
A message-like event that failed to deserialize.
FailedToParseState
A state event that failed to deserialize.
Fields
event_type: StateEventTypeThe event type.
CallInvite
An m.call.invite event
RtcNotification
An m.rtc.notification event
Implementations
Sourceimpl TimelineItemContent
impl TimelineItemContent
pub fn as_msglike(&self) -> Option<&MsgLikeContent>
Sourcepub fn as_live_location_state(&self) -> Option<&LiveLocationState>
pub fn as_live_location_state(&self) -> Option<&LiveLocationState>
If self is of the MsgLike variant with a
LiveLocation kind, return the inner
LiveLocationState.
Sourcepub fn is_live_location(&self) -> bool
pub fn is_live_location(&self) -> bool
Check whether this item’s content is a
LiveLocation.
Sourcepub fn as_message(&self) -> Option<&Message>
pub fn as_message(&self) -> Option<&Message>
Sourcepub fn is_message(&self) -> bool
pub fn is_message(&self) -> bool
Check whether this item’s content is a
Message.
pub fn as_sticker(&self) -> Option<&Sticker>
Sourcepub fn is_sticker(&self) -> bool
pub fn is_sticker(&self) -> bool
Check whether this item’s content is a
Sticker.
Sourcepub fn as_unable_to_decrypt(&self) -> Option<&EncryptedMessage>
pub fn as_unable_to_decrypt(&self) -> Option<&EncryptedMessage>
If self is of the UnableToDecrypt
variant, return the inner EncryptedMessage.
Sourcepub fn is_unable_to_decrypt(&self) -> bool
pub fn is_unable_to_decrypt(&self) -> bool
Check whether this item’s content is a
UnableToDecrypt.
pub fn is_redacted(&self) -> bool
Sourcepub fn thread_root(&self) -> Option<OwnedEventId>
pub fn thread_root(&self) -> Option<OwnedEventId>
Event ID of the thread root, if this is a message in a thread.
Sourcepub fn in_reply_to(&self) -> Option<InReplyToDetails>
pub fn in_reply_to(&self) -> Option<InReplyToDetails>
Get the event this message is replying to, if any.
Sourcepub fn reactions(&self) -> Option<&ReactionsByKeyBySender>
pub fn reactions(&self) -> Option<&ReactionsByKeyBySender>
Return the reactions, grouped by key and then by sender, for a given content.
Sourcepub fn thread_summary(&self) -> Option<ThreadSummary>
pub fn thread_summary(&self) -> Option<ThreadSummary>
Information about the thread this item is the root for.
pub fn with_reactions(&self, reactions: ReactionsByKeyBySender) -> Self