pub struct EditRevision {
pub content: TimelineItemContent,
pub timestamp: Option<MilliSecondsSinceUnixEpoch>,
}Expand description
A single revision in the edit history of a message.
Created on-demand by querying the Event Cache for all m.replace relations
targeting a particular event.
Fields
content: TimelineItemContentThe timeline item content after this revision.
timestamp: Option<MilliSecondsSinceUnixEpoch>The timestamp of the event that created this revision.