pub struct GalleryConfig { /* private fields */ }Available on crate feature
unstable-msc4274 only.Expand description
Configuration for sending a gallery.
This duplicates matrix_sdk::attachment::GalleryConfig but uses an
AttachmentSource so that we can delay loading the actual data until we’re
inside the SendGallery future. This allows Timeline::send_gallery to
return early without blocking the caller.
Implementations
Sourceimpl GalleryConfig
impl GalleryConfig
Sourcepub fn txn_id(self, txn_id: OwnedTransactionId) -> Self
pub fn txn_id(self, txn_id: OwnedTransactionId) -> Self
Set the transaction ID to send.
Arguments
txn_id- A unique ID that can be attached to aMessageEventheld in its unsigned field astransaction_id. If not given, one is created for the message.
Sourcepub fn add_item(self, item: GalleryItemInfo) -> Self
pub fn add_item(self, item: GalleryItemInfo) -> Self
Sourcepub fn caption(self, caption: Option<TextMessageEventContent>) -> Self
pub fn caption(self, caption: Option<TextMessageEventContent>) -> Self
Sourcepub fn in_reply_to(self, event_id: Option<OwnedEventId>) -> Self
pub fn in_reply_to(self, event_id: Option<OwnedEventId>) -> Self
Sourcepub fn extra_content(self, extra_content: Option<Map<String, Value>>) -> Self
pub fn extra_content(self, extra_content: Option<Map<String, Value>>) -> Self
Set additional top-level fields for the gallery event’s content.
Objects are merged recursively; the event’s own fields take precedence
on conflicts. To add fields to individual items, use
GalleryItemInfo::extra_content.