pub struct PollResult {
pub question: String,
pub kind: PollKind,
pub max_selections: u64,
pub answers: Vec<PollResultAnswer>,
pub votes: HashMap<String, Vec<OwnedUserId>>,
pub end_time: Option<MilliSecondsSinceUnixEpoch>,
pub has_been_edited: bool,
}Expand description
The results of a poll.
Fields
question: StringThe question of the poll.
kind: PollKindThe kind of the poll.
max_selections: u64The maximum number of responses a user is able to select.
answers: Vec<PollResultAnswer>The possible answers to the poll.
votes: HashMap<String, Vec<OwnedUserId>>The current votes of the poll.
This is a map from answer ID to the list of user IDs that voted for that answer.
end_time: Option<MilliSecondsSinceUnixEpoch>The time when the poll ended.
If this is set the poll has ended, otherwise the poll is still ongoing.
has_been_edited: boolWhether the poll was edited.