pub struct PollState { /* private fields */ }Expand description
Holds the state of a poll.
This struct should be created for each poll start event handled and then updated whenever handling any poll response or poll end event that relates to the same poll start event.
Implementations
Sourceimpl PollState
impl PollState
Sourcepub fn fallback_text(&self) -> Option<String>
pub fn fallback_text(&self) -> Option<String>
Get the text representation of the poll, for clients that don’t support them.
Sourcepub fn results(&self) -> PollResult
pub fn results(&self) -> PollResult
Compute the current results of the poll.