pub struct TimelineItem { /* private fields */ }Expand description
A single entry in timeline.
Implementations
Sourceimpl TimelineItem
impl TimelineItem
Sourcepub fn kind(&self) -> &TimelineItemKind
pub fn kind(&self) -> &TimelineItemKind
Get the TimelineItemKind of this item.
Sourcepub fn as_event(&self) -> Option<&EventTimelineItem>
pub fn as_event(&self) -> Option<&EventTimelineItem>
Get the inner EventTimelineItem, if this is a
TimelineItemKind::Event.
Sourcepub fn as_virtual(&self) -> Option<&VirtualTimelineItem>
pub fn as_virtual(&self) -> Option<&VirtualTimelineItem>
Get the inner VirtualTimelineItem, if this is a
TimelineItemKind::Virtual.
Sourcepub fn unique_id(&self) -> &TimelineUniqueId
pub fn unique_id(&self) -> &TimelineUniqueId
Get a unique ID for this timeline item.
It identifies the item on a best-effort basis. For instance, edits to an
EventTimelineItem will not change the ID of the enclosing
TimelineItem. For some virtual items like date dividers, identity
isn’t easy to define though and you might see a new ID getting generated
for a date divider that you perceive to be “the same” as a previous one.
Sourcepub fn is_date_divider(&self) -> bool
pub fn is_date_divider(&self) -> bool
Check whether this item is a (virtual) date divider.
Sourcepub fn is_timeline_start(&self) -> bool
pub fn is_timeline_start(&self) -> bool
Check whether this item is a (virtual) timeline start item.